@@ -1,3 +1,10 @@
+import sys
+import os
+
+here = os.path.split(os.path.abspath(__file__))[0]
+root = os.path.abspath(os.path.join(here, '../../'))
+sys.path[0:0] = [root]
+
 from streamparse.bolt import Bolt
 
 
